Runs grouped stability selection over a grid of subsampling fractions and cutoff values.
Arguments
- design
An
fda_designobject.- selector
Base selector passed to
fit_stability().- sample_fraction_grid
Candidate subsampling fractions.
- cutoff_grid
Candidate cutoff values.
- keep_fits
Should the fitted objects be stored in the result?
- seed
Optional seed used to create deterministic per-grid seeds.
- ...
Additional arguments passed to
fit_stability().