Runs multiple selection workflows on the same fda_design object and
returns both the fitted objects and a comparison table.
Arguments
- design
An
fda_designobject.- methods
Methods to run. Supported values are
"stability","interval","selectboost","plain_selectboost", and"fdboost".- stability_args, interval_args, selectboost_args, plain_selectboost_args
Named lists of arguments passed to the corresponding fitting functions.
- fdboost_model
Optional fitted
FDboostobject used whenmethodsincludes"fdboost".- fdboost_args
Additional arguments passed to
fdboost_stability_selection().
Examples
sim <- simulate_fda_scenario(n = 24, grid_length = 16, seed = 1)
comparison <- compare_selection_methods(
sim$design,
methods = c("selectboost", "plain_selectboost"),
selectboost_args = list(B = 3, steps.seq = 0.5, c0lim = FALSE),
plain_selectboost_args = list(B = 3, steps.seq = 0.5, c0lim = FALSE)
)
summary(comparison)
#> FDA method comparison summary
#> methods: selectboost, plain_selectboost
#> c0 n_selected_features n_selected_groups mean_feature_selection
#> c0 = 0.5 26 4 0.5196078
#> c0 = 0.5 29 4 0.5980392
#> max_feature_selection mean_group_selection max_group_selection
#> 1 0.7447917 1
#> 1 0.7864583 1
#> method
#> selectboost
#> plain_selectboost